@@ -26,6 +26,8 @@ func TestFilesystem(t *testing.T) {
 		filePatterns   []string
 		helmSet        []string
 		helmValuesFile []string
+		skipFiles      []string
+		skipDirs       []string
 	}
 	tests := []struct {
 		name   string
@@ -40,14 +42,42 @@ func TestFilesystem(t *testing.T) {
 			},
 			golden: "testdata/gomod.json.golden",
 		},
+		{
+			name: "gomod with skip files",
+			args: args{
+				securityChecks: "vuln",
+				input:          "testdata/fixtures/fs/gomod",
+				skipFiles:      []string{"/testdata/fixtures/fs/gomod/submod2/go.mod"},
+			},
+			golden: "testdata/gomod-skip.json.golden",
+		},
+		{
+			name: "gomod with skip dirs",
+			args: args{
+				securityChecks: "vuln",
+				input:          "testdata/fixtures/fs/gomod",
+				skipDirs:       []string{"/testdata/fixtures/fs/gomod/submod2"},
+			},
+			golden: "testdata/gomod-skip.json.golden",
+		},
 		{
 			name: "nodejs",
 			args: args{
 				securityChecks: "vuln",
 				input:          "testdata/fixtures/fs/nodejs",
+				listAllPkgs:    true,
 			},
 			golden: "testdata/nodejs.json.golden",
 		},
+		{
+			name: "yarn",
+			args: args{
+				securityChecks: "vuln",
+				input:          "testdata/fixtures/fs/yarn",
+				listAllPkgs:    true,
+			},
+			golden: "testdata/yarn.json.golden",
+		},
 		{
 			name: "pnpm",
 			args: args{
@@ -90,6 +120,24 @@ func TestFilesystem(t *testing.T) {
 			},
 			golden: "testdata/conan.json.golden",
 		},
+		{
+			name: "nuget",
+			args: args{
+				securityChecks: "vuln",
+				listAllPkgs:    true,
+				input:          "testdata/fixtures/fs/nuget",
+			},
+			golden: "testdata/nuget.json.golden",
+		},
+		{
+			name: "dotnet",
+			args: args{
+				securityChecks: "vuln",
+				listAllPkgs:    true,
+				input:          "testdata/fixtures/fs/dotnet",
+			},
+			golden: "testdata/dotnet.json.golden",
+		},
 		{
 			name: "dockerfile",
 			args: args{
@@ -244,6 +292,18 @@ func TestFilesystem(t *testing.T) {
 				}
 			}
 
+			if len(tt.args.skipFiles) != 0 {
+				for _, skipFile := range tt.args.skipFiles {
+					osArgs = append(osArgs, "--skip-files", skipFile)
+				}
+			}
+
+			if len(tt.args.skipDirs) != 0 {
+				for _, skipDir := range tt.args.skipDirs {
+					osArgs = append(osArgs, "--skip-dirs", skipDir)
+				}
+			}
+
 			// Setup the output file
 			outputFile := filepath.Join(t.TempDir(), "output.json")
 			if *update {
