@@ -10,6 +10,7 @@ import (
 	"strings"
 	"sync"
 
+	"github.com/samber/lo"
 	"golang.org/x/exp/slices"
 	"golang.org/x/sync/semaphore"
 	"golang.org/x/xerrors"
@@ -38,16 +39,22 @@ var (
 
 // AnalyzerOptions is used to initialize analyzers
 type AnalyzerOptions struct {
-	Group               Group
-	FilePatterns        []string
-	DisabledAnalyzers   []Type
-	SecretScannerOption SecretScannerOption
+	Group                Group
+	FilePatterns         []string
+	DisabledAnalyzers    []Type
+	SecretScannerOption  SecretScannerOption
+	LicenseScannerOption LicenseScannerOption
 }
 
 type SecretScannerOption struct {
 	ConfigPath string
 }
 
+type LicenseScannerOption struct {
+	// Use license classifier to get better results though the classification is expensive.
+	Full bool
+}
+
 ////////////////
 // Interfaces //
 ////////////////
@@ -138,8 +145,13 @@ type AnalysisResult struct {
 	Licenses             []types.LicenseFile
 	SystemInstalledFiles []string // A list of files installed by OS package manager
 
+	// Files holds necessary file contents for the respective post-handler
 	Files map[types.HandlerType][]types.File
 
+	// Digests contains SHA-256 digests of unpackaged files
+	// used to search for SBOM attestation.
+	Digests map[string]string
+
 	// For Red Hat
 	BuildInfo *types.BuildInfo
 
@@ -157,7 +169,7 @@ func NewAnalysisResult() *AnalysisResult {
 func (r *AnalysisResult) isEmpty() bool {
 	return r.OS == nil && r.Repository == nil && len(r.PackageInfos) == 0 && len(r.Applications) == 0 &&
 		len(r.Secrets) == 0 && len(r.Licenses) == 0 && len(r.SystemInstalledFiles) == 0 &&
-		r.BuildInfo == nil && len(r.Files) == 0 && len(r.CustomResources) == 0
+		r.BuildInfo == nil && len(r.Files) == 0 && len(r.Digests) == 0 && len(r.CustomResources) == 0
 }
 
 func (r *AnalysisResult) Sort() {
@@ -254,6 +266,11 @@ func (r *AnalysisResult) Merge(new *AnalysisResult) {
 		r.Applications = append(r.Applications, new.Applications...)
 	}
 
+	// Merge SHA-256 digests of unpackaged files
+	if new.Digests != nil {
+		r.Digests = lo.Assign(r.Digests, new.Digests)
+	}
+
 	for t, files := range new.Files {
 		if v, ok := r.Files[t]; ok {
 			r.Files[t] = append(v, files...)
