@@ -369,6 +369,11 @@ func Test_helmConfigAnalyzer_Required(t *testing.T) {
 			filePath: "testdata/testchart/Chart.yaml",
 			want:     true,
 		},
+		{
+			name:     "yaml - shorthand",
+			filePath: "testdata/testchart/templates/deployment.yml",
+			want:     true,
+		},
 		{
 			name:     "tpl",
 			filePath: "testdata/testchart/templates/_helpers.tpl",
