@@ -27,8 +27,13 @@ func Test_rustBinaryLibraryAnalyzer_Analyze(t *testing.T) {
 						Type:     types.RustBinary,
 						FilePath: "testdata/executable_rust",
 						Libraries: []types.Package{
-							{Name: "crate_with_features", Version: "0.1.0"},
-							{Name: "library_crate", Version: "0.1.0", Indirect: true},
+							{
+								ID:        "crate_with_features@0.1.0",
+								Name:      "crate_with_features",
+								Version:   "0.1.0",
+								DependsOn: []string{"library_crate@0.1.0"},
+							},
+							{ID: "library_crate@0.1.0", Name: "library_crate", Version: "0.1.0", Indirect: true},
 						},
 					},
 				},
