@@ -64,11 +64,6 @@ func (a licenseFileAnalyzer) Analyze(_ context.Context, input analyzer.AnalysisI
 		return nil, nil
 	}
 
-	content, err := io.ReadAll(input.Content)
-	if err != nil {
-		return nil, xerrors.Errorf("read error %s: %w", input.FilePath, err)
-	}
-
 	filePath := input.FilePath
 	// Files extracted from the image have an empty input.Dir.
 	// Also, paths to these files do not have "/" prefix.
@@ -77,7 +72,7 @@ func (a licenseFileAnalyzer) Analyze(_ context.Context, input analyzer.AnalysisI
 		filePath = fmt.Sprintf("/%s", filePath)
 	}
 
-	lf, err := licensing.FullClassify(filePath, content)
+	lf, err := licensing.Classify(filePath, input.Content)
 	if err != nil {
 		return nil, xerrors.Errorf("license classification error: %w", err)
 	} else if len(lf.Findings) == 0 {
@@ -85,7 +80,7 @@ func (a licenseFileAnalyzer) Analyze(_ context.Context, input analyzer.AnalysisI
 	}
 
 	return &analyzer.AnalysisResult{
-		Licenses: []types.LicenseFile{lf},
+		Licenses: []types.LicenseFile{*lf},
 	}, nil
 }
 
