@@ -8,12 +8,16 @@ import (
 	"io/fs"
 	"os"
 	"path/filepath"
+	"sort"
 	"strings"
 
-	"github.com/liamg/memoryfs"
 	"github.com/samber/lo"
 	"golang.org/x/xerrors"
 
+	"github.com/aquasecurity/memoryfs"
+
+	"github.com/aquasecurity/defsec/pkg/scanners/azure/arm"
+
 	"github.com/aquasecurity/defsec/pkg/detection"
 	"github.com/aquasecurity/defsec/pkg/scan"
 	"github.com/aquasecurity/defsec/pkg/scanners"
@@ -163,8 +167,7 @@ func newMisconfPostHandler(artifactOpt artifact.Option) (handler.PostHandler, er
 	}
 
 	if opt.RegoOnly {
-		opts = append(opts, tfscanner.ScannerWithRegoOnly(true))
-		opts = append(opts, cfscanner.ScannerWithRegoOnly(true))
+		opts = append(opts, options.ScannerWithRegoOnly(true))
 	}
 
 	if len(policyPaths) > 0 {
@@ -185,6 +188,7 @@ func newMisconfPostHandler(artifactOpt artifact.Option) (handler.PostHandler, er
 	return misconfPostHandler{
 		filePatterns: artifactOpt.FilePatterns,
 		scanners: map[string]scanners.FSScanner{
+			types.AzureARM:       arm.New(opts...),
 			types.Terraform:      tfscanner.New(tfOpts...),
 			types.CloudFormation: cfscanner.New(opts...),
 			types.Dockerfile:     dfscanner.NewScanner(opts...),
@@ -224,6 +228,7 @@ func addHelmOpts(opts []options.ScannerOption, scannerOption config.ScannerOptio
 }
 
 var enabledDefsecTypes = map[detection.FileType]string{
+	detection.FileTypeAzureARM:       types.AzureARM,
 	detection.FileTypeCloudFormation: types.CloudFormation,
 	detection.FileTypeTerraform:      types.Terraform,
 	detection.FileTypeDockerfile:     types.Dockerfile,
@@ -288,10 +293,31 @@ func (h misconfPostHandler) Handle(ctx context.Context, result *analyzer.Analysi
 			return xerrors.Errorf("scan config error: %w", err)
 		}
 
-		misconfs = append(misconfs, resultsToMisconf(t, scanner.Name(), results)...)
+		misconfs = append(misconfs, ResultsToMisconf(t, scanner.Name(), results)...)
 	}
 
 	// Add misconfigurations
+	for _, misconf := range misconfs {
+		sort.Slice(misconf.Successes, func(i, j int) bool {
+			if misconf.Successes[i].AVDID == misconf.Successes[j].AVDID {
+				return misconf.Successes[i].StartLine < misconf.Successes[j].StartLine
+			}
+			return misconf.Successes[i].AVDID < misconf.Successes[j].AVDID
+		})
+		sort.Slice(misconf.Warnings, func(i, j int) bool {
+			if misconf.Warnings[i].AVDID == misconf.Warnings[j].AVDID {
+				return misconf.Warnings[i].StartLine < misconf.Warnings[j].StartLine
+			}
+			return misconf.Warnings[i].AVDID < misconf.Warnings[j].AVDID
+		})
+		sort.Slice(misconf.Failures, func(i, j int) bool {
+			if misconf.Failures[i].AVDID == misconf.Failures[j].AVDID {
+				return misconf.Failures[i].StartLine < misconf.Failures[j].StartLine
+			}
+			return misconf.Failures[i].AVDID < misconf.Failures[j].AVDID
+		})
+	}
+
 	blob.Misconfigurations = misconfs
 
 	return nil
@@ -309,7 +335,8 @@ func (h misconfPostHandler) Priority() int {
 	return types.MisconfPostHandlerPriority
 }
 
-func resultsToMisconf(configType string, scannerName string, results scan.Results) []types.Misconfiguration {
+// This function is exported for trivy-plugin-aqua purposes only
+func ResultsToMisconf(configType string, scannerName string, results scan.Results) []types.Misconfiguration {
 	misconfs := map[string]types.Misconfiguration{}
 
 	for _, result := range results {
