@@ -35,6 +35,7 @@ type Package struct {
 	SrcRelease string   `json:",omitempty"`
 	SrcEpoch   int      `json:",omitempty"`
 	Licenses   []string `json:",omitempty"`
+	Maintainer string   `json:",omitempty"`
 
 	Modularitylabel string     `json:",omitempty"` // only for Red Hat based distributions
 	BuildInfo       *BuildInfo `json:",omitempty"` // only for Red Hat
@@ -109,6 +110,7 @@ const (
 	ArtifactCycloneDX        ArtifactType = "cyclonedx"
 	ArtifactSPDX             ArtifactType = "spdx"
 	ArtifactAWSAccount       ArtifactType = "aws_account"
+	ArtifactVM               ArtifactType = "vm"
 )
 
 // ArtifactReference represents a reference of container image, local filesystem and repository
